@@ -2,6 +2,8 @@ from pkgutil import extend_path
 __path__ = extend_path(__path__, __name__)
 
 from .backends import *
-from .views import *
+from .models import *
 from .template_tags import *
 from .with_section import *
+from .utils import *
+from .views import *
